

*Stata and Python 3D Graph of Marginal Predictions 


use nls, clear
keep msp age hours

svyset _n
svy: logistic msp age hour c.age#c.hours
quietly margins, at(age=(18(5)50) hours=(10(5)60)) vce(unconditional) saving(marginal_predictions, replace)

use marginal_predictions, clear
rename _at1 age
rename _at2 hours
rename _margin pr_married
save marginal_predictions, replace


python:
import pandas as pd
import numpy as np 
import matplotlib
import matplotlib.pyplot as plt 
matplotlib.use('TkAgg')
data = pd.read_stata("marginal_predictions.dta")
ax = plt.axes(projection='3d')
ax.plot_trisurf(data['age'], data['hours'], data['pr_married'], cmap=plt.cm.Spectral_r)

ax.set_xticks(np.arange(18, 50, step=5))
ax.set_yticks(np.arange(10, 70, step=10))
ax.set_zticks(np.arange( 0, 1.2, step=0.2))

ax.set_title("Probability of Getting Married by Age and Hours Worked")
ax.set_xlabel("Age (Years)")
ax.set_ylabel("Hours Worked per Week")

ax.zaxis.set_rotate_label(False)

ax.set_zlabel("Probability of Marriage", rotation=90)

ax.view_init(elev=30, azim=240)

plt.savefig("Margins3d.png", dpi=1200)
end


